@@ -145,7 +145,7 @@ The id of an existing invoice to be copied.  This is optional if customer or a n
 
 =item items.amount
 
-Amount of the invoice item (the smallest unit of your currency). Example: 100 = $1.00USD [min value: -9999900, max value: 9999900] (B<required>) 
+Amount of the invoice item (the smallest unit of your currency). Example: 100 = $1.00USD (B<required>) 
 
 =item items.description
 
@@ -173,7 +173,7 @@ The tax ID of the tax charge in the invoice item.
 
 =item lateFee
 
-The late fee amount that will be added to the invoice total is the due date is past due.  Value provided must be in the smallest unit of your currency. Example: 100 = $1.00USD [max value: 9999900] 
+The late fee amount that will be added to the invoice total is the due date is past due.  Value provided must be in the smallest unit of your currency. Example: 100 = $1.00USD 
 
 =item memo
 
@@ -430,7 +430,7 @@ User defined invoice id. If not provided the system will generate a numeric id.
 
 =item C<items.amount>
 
-Amount of the invoice item in the smallest unit of your currency. Example: 100 = $1.00USD [min value: -9999900, max value: 9999900] (B<required>) 
+Amount of the invoice item in the smallest unit of your currency. Example: 100 = $1.00USD (B<required>) 
 
 =item C<items.description>
 
@@ -458,7 +458,7 @@ The tax ID of the tax charge in the invoice item.
 
 =item C<lateFee>
 
-The late fee amount that will be added to the invoice total is the due date is past due.  Value provided must be in the smallest unit of your currency. Example: 100 = $1.00USD [max value: 9999900] 
+The late fee amount that will be added to the invoice total is the due date is past due.  Value provided must be in the smallest unit of your currency. Example: 100 = $1.00USD 
 
 =item C<memo>
 
@@ -538,11 +538,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.2.0
+1.5.0
 
 =head1 LICENSE
 
-Copyright (c) 2013 - 2015 MasterCard International Incorporated
+Copyright (c) 2013 - 2016 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
