@@ -73,7 +73,7 @@ Address of the cardholder if needed. [max length: 255]
 
 =item card.addressState
 
-State of residence of the cardholder. For the US, this is a 2-digit USPS code. [max length: 255, min length: 2] 
+State of residence of the cardholder. For the US, this is a 2-digit USPS code. [max length: 255] 
 
 =item card.addressZip
 
@@ -115,6 +115,146 @@ Free form text field to be used as a description of the payment. This field is e
 
 ID of invoice for which this payment is being made. 
 
+
+
+=item order.commodityCode
+
+Standard classification code for products and services. [max length: 5] 
+
+=item order.customer
+
+ID of the customer associated with the order. 
+
+=item order.customerEmail
+
+Customer email address. 
+
+=item order.customerName
+
+Customer name. 
+
+=item order.customerNote
+
+Additional notes provided by the customer. [max length: 255] 
+
+=item order.customerReference
+
+A merchant reference for the customer. 
+
+
+
+=item order.items.amount
+
+Cost of the item. 
+
+=item order.items.description
+
+Description of the item. 
+
+=item order.items.name
+
+Item name. 
+
+=item order.items.product
+
+Product information associated with the item. 
+
+=item order.items.quantity
+
+Quantity of the item contained in the order [min value: 1, max value: 999999, default: 1] (B<required>) 
+
+=item order.items.reference
+
+A merchant reference for the item. [max length: 255] 
+
+=item order.items.tax
+
+Taxes associated with the item. 
+
+=item order.merchantNote
+
+Additional notes provided by the merchant. [max length: 255] 
+
+=item order.payment
+
+ID of the payment associated with the order. 
+
+=item order.reference
+
+A merchant reference for the order. [max length: 255] 
+
+
+
+=item order.shippingAddress.city
+
+City, town, or municipality. [max length: 255, min length: 2] 
+
+=item order.shippingAddress.country
+
+2-character country code. [max length: 2, min length: 2] 
+
+=item order.shippingAddress.line1
+
+Street address. [max length: 255] 
+
+=item order.shippingAddress.line2
+
+(Opt) Street address continued. [max length: 255] 
+
+=item order.shippingAddress.name
+
+Name of the entity being shipped to. [max length: 255] 
+
+=item order.shippingAddress.state
+
+State or province. [max length: 255] 
+
+=item order.shippingAddress.zip
+
+Postal code. [max length: 32] 
+
+
+
+=item order.shippingFromAddress.city
+
+City, town, or municipality. [max length: 255, min length: 2] 
+
+=item order.shippingFromAddress.country
+
+2-character country code. [max length: 2, min length: 2] 
+
+=item order.shippingFromAddress.line1
+
+Street address. [max length: 255] 
+
+=item order.shippingFromAddress.line2
+
+(Opt) Street address continued. [max length: 255] 
+
+=item order.shippingFromAddress.name
+
+Name of the entity performing the shipping. [max length: 255] 
+
+=item order.shippingFromAddress.state
+
+State or province. [max length: 255] 
+
+=item order.shippingFromAddress.zip
+
+Postal code. [max length: 32] 
+
+=item order.shippingName
+
+Name of the entity being shipped to. 
+
+=item order.source
+
+Order source. [default: WEB] (B<required>) 
+
+=item order.status
+
+Status of the order. [default: INCOMPLETE] (B<required>) 
+
 =item reference
 
 Custom reference field to be used with outside systems. 
@@ -133,6 +273,10 @@ Merchant name. (B<required>)
 
 Merchant contact phone number. 
 
+=item taxExempt
+
+Specify true to indicate that the payment is tax-exempt. 
+
 =item token
 
 If specified, card associated with card token will be used. [max length: 255] 
@@ -258,11 +402,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.2.0
+1.5.0
 
 =head1 LICENSE
 
-Copyright (c) 2013 - 2015 MasterCard International Incorporated
+Copyright (c) 2013 - 2016 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
